%% Daten lesen nur beim ersten Durchlauf!
% Danach reicht es Daten einzuschrnken 
Daten = xlsread('Input_30DAX.xlsx','A3:AE1273');

%% Daten einschrnken
%Spalten der DAX 30: A:AE  (XLSX-Tabelle)
%Zeile 1: Lauf-Nr. der Aktien, Zeile 2: Namen der Aktien, ab 3.Zeile Daten
%2004: A3:AE259      (In der Matrix "Daten" 1:257)
%2005: A260:AE515    (In der Matrix "Daten" 258:513)
%2006: A516:AE770    (In der Matrix "Daten" 514:768)
%2007: A771:AE1021   (In der Matrix "Daten" 769:1019)
%2008: A1022:AE1273  (In der Matrix "Daten" 1020:1271)
%2009: A1274:AE1525  (In der Matrix "Daten" 1272:1523)
Input = Daten(258:1019,:);

%% MVE: Ermittlung von Strukturmatrix und Zentrum
Fehler=0.01;
[Q , c] = MVE(Input', Fehler);

%% Ermittlung der Parameter resultierend aus den Daten
Erwartung = c;   %Renditenerwartungsvektor als Spaltenvektor
KovMatrix = inv(Q);     %Kovarianzmatrix
Eins = ones(length(Erwartung),1);    %Eins-Vektor aus nur einsen
%E_An = exp(Erwartung*250)-1         %Annualisierte diskrete Renditenerwartung
%Annualisierte Volatilitten
%for i=1:length(Erwartung)
%Vol_An(i,1) = sqrt(KovMatrix(i,i)*250)
%end

%Parameter a, b und c
a = Erwartung' * (KovMatrix \ Erwartung);
b = Eins' * (KovMatrix \ Erwartung);
c = Eins' * (KovMatrix \ Eins);

%Parameter g und h
g = KovMatrix \(a*Eins - b*Erwartung) / (a*c - b*b);
h = KovMatrix \(c*Erwartung - b*Eins) / (a*c - b*b);


%% das Minimum-Varianz Portfolio
% Das Minimum-Varianz Portfolio hat die Renditenerwartung b/c. 
% Daraus ergibt sich die Aufteilung des Portfolios X mit:
X = g + (b/c)*h;
% diskrete Renditenerwartung des gesamten Portfolios fr ein Jahr
%exp(X'*Erwartung*250)-1
% Jahresvarianz des gesamten Portfolios
%X'*KovMatrix*X*250
% Jahresvolatilitt des gesamten Portfolios
%sqrt(X'*KovMatrix*X*250)


%% Effizienzkurve nach Markowitz, ohne Nicht-Negativittsbedingung
% Ausgegeben werden die Jahresvolatilitt gegen die Jahresrenditenerwartung
% des gesamten Portfolios. Dabei wird unterstellt, dass das Brsenjahr 250
% Brsentage hat.

% 1. Renditenerwartung des ganzen Portfolios ist im Intervall zwischen 
Emin = b/c;
Emax = max(Erwartung);


% 2. Ein Vektor der Gesamtrenditenerwartung wird fr das Plot erzeugt:
% Die Schrittlnge ist sogewhlt, dass insgesamt 300 Portfolios berechnet
% werden.
Schritt=(Emax-Emin)/700;
E = Emin:Schritt:Emax;
% DieLnge des Vektors E ist:
n = length(E);

% 3. Ein Vektor der entsprechenden Volatilitt wird durch Einsetzen der
% Paramenter in die Gleichung fr die Volatilitt erzeugt:
s=sqrt((c.*E.*E-2*b.*E+a)/(a*c-b*b));

% 4. Die bereits berechneten Werte werden annualisiert, wobei unterstellt
% ist, dass das Brsenjahr 250 Tage hat:
E=250*E;
s=sqrt(250)*s;

% 5. Nun wird die Effizienzkurve geplottet
plot (s,E)
xlabel('Unschrfe')
ylabel('Annualisierte Renditen des Portfolios mit hchster Zugehrigkeit')
title('Effizienzkurve nach Fuzzy Modell (Dateninput: Tagesschwerpunkte 2008)')
